#!/usr/bin/env python3

# Copyright © 2020-2025, Meheret Tesfaye Batu <meherett.batu@gmail.com>
# Distributed under the MIT software license, see the accompanying
# file COPYING or https://opensource.org/license/mit

from ..slip44 import CoinTypes
from ..ecc import SLIP10Secp256k1ECC
from ..const import (
    Info, Entropies, Mnemonics, Seeds, HDs, Addresses, AddressTypes, Networks, XPrivateKeyVersions, XPublicKeyVersions
)
from .icryptocurrency import (
    ICryptocurrency, INetwork
)


class Mainnet(INetwork):

    HRP = "bnb"
    XPRIVATE_KEY_VERSIONS = XPrivateKeyVersions({
        "P2PKH": 0x488ade4
    })
    XPUBLIC_KEY_VERSIONS = XPublicKeyVersions({
        "P2PKH": 0x488b21e
    })
    WIF_PREFIX = 0x80


class Binance(ICryptocurrency):

    NAME = "Binance"
    SYMBOL = "BNB"
    INFO = Info({
        "SOURCE_CODE": "https://github.com/bnb-chain/bsc",
        "WHITEPAPER": "https://github.com/bnb-chain/whitepaper",
        "WEBSITES": [
            "https://www.bnbchain.org"
        ]
    })
    ECC = SLIP10Secp256k1ECC
    COIN_TYPE = CoinTypes.Binance
    NETWORKS = Networks({
        "MAINNET": Mainnet
    })
    DEFAULT_NETWORK = NETWORKS.MAINNET
    ENTROPIES = Entropies({
        "BIP39"
    })
    MNEMONICS = Mnemonics({
        "BIP39"
    })
    SEEDS = Seeds({
        "BIP39"
    })
    HDS = HDs({
        "BIP32", "BIP44"
    })
    DEFAULT_HD = HDS.BIP44
    ADDRESSES = Addresses({
        "COSMOS": "Cosmos", "ETHEREUM": "Ethereum"
    })
    DEFAULT_ADDRESS = ADDRESSES.COSMOS
    ADDRESS_TYPES = AddressTypes({
        "CHAIN": "chain",
        "SMART_CHAIN": "smart-chain"
    })
    DEFAULT_ADDRESS_TYPE = ADDRESS_TYPES.CHAIN
